@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 41 "/builds/slave/2.0-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 41 "/builds/slave/rel-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
 */
 
 const Cc = Components.classes;
@@ -69,7 +69,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function bls_gABI() {
   catch (e) {
     LOG("BlockList Global gABI: XPCOM ABI unknown.");
   }
-//@line 110 "/builds/slave/2.0-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 110 "/builds/slave/rel-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
   // Mac universal build should report a different ABI than either macppc
   // or mactel.
   let macutils = Cc["@mozilla.org/xpcom/mac-utils;1"].
@@ -77,7 +77,7 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function bls_gABI() {
 
   if (macutils.isUniversalBinary)
     abi += "-u-" + macutils.architecturesInBinary;
-//@line 118 "/builds/slave/2.0-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 118 "/builds/slave/rel-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
   return abi;
 });
 
@@ -209,7 +209,8 @@ function getLocale() {
   try {
       // Get the default branch
       var defaultPrefs = gPref.getDefaultBranch(null);
-      return defaultPrefs.getCharPref(PREF_GENERAL_USERAGENT_LOCALE);
+      return defaultPrefs.getComplexPref(PREF_GENERAL_USERAGENT_LOCALE,
+                                         Ci.nsIPrefLocalizedString).data;
   } catch (e) {}
 
   return gPref.getCharPref(PREF_GENERAL_USERAGENT_LOCALE);
@@ -395,12 +396,8 @@ Blocklist.prototype = {
     var pingCountVersion = getPref("getIntPref", PREF_BLOCKLIST_PINGCOUNTVERSION, 0);
     var pingCountTotal = getPref("getIntPref", PREF_BLOCKLIST_PINGCOUNTTOTAL, 1);
     var daysSinceLastPing = 0;
-    if (pingCountVersion < 1 || pingCountTotal < 1) {
-      daysSinceLastPing = pingCountVersion == 0 ? "new" : "reset";
-      if (pingCountVersion < 1)
-        pingCountVersion = 1;
-      if (pingCountTotal < 1)
-        pingCountTotal = 1;
+    if (pingCountVersion == 0) {
+      daysSinceLastPing = "new";
     }
     else {
       // Seconds in one day is used because nsIUpdateTimerManager stores the
@@ -420,6 +417,11 @@ Blocklist.prototype = {
       }
     }
 
+    if (pingCountVersion < 1)
+      pingCountVersion = 1;
+    if (pingCountTotal < 1)
+      pingCountTotal = 1;
+
     dsURI = dsURI.replace(/%APP_ID%/g, gApp.ID);
     dsURI = dsURI.replace(/%APP_VERSION%/g, gApp.version);
     dsURI = dsURI.replace(/%PRODUCT%/g, gApp.name);
@@ -566,7 +568,7 @@ Blocklist.prototype = {
   },
 
   /**
-//@line 655 "/builds/slave/2.0-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
+//@line 657 "/builds/slave/rel-osx64-xr/build/toolkit/mozapps/extensions/nsBlocklistService.js"
    */
 
   _loadBlocklistFromFile: function(file) {
