@@ -27,14 +27,14 @@ pref("security.ssl3.rsa_1024_des_cbc_sha", false);
 pref("security.ssl3.rsa_rc4_40_md5", false);
 pref("security.ssl3.rsa_rc2_40_md5", false);
 // Camellia is broken on Windows CE for now, see bug 508113
-//@line 31 "/builds/slave/m-2.0-osx64-xr/build/netwerk/base/public/security-prefs.js"
+//@line 31 "/builds/slave/rel-osx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_dss_camellia_256_sha", true);
 pref("security.ssl3.rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_rsa_camellia_128_sha", true);
 pref("security.ssl3.dhe_dss_camellia_128_sha", true);
 pref("security.ssl3.rsa_camellia_128_sha", true);
-//@line 38 "/builds/slave/m-2.0-osx64-xr/build/netwerk/base/public/security-prefs.js"
+//@line 38 "/builds/slave/rel-osx64-xr/build/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_aes_256_sha", true);
 pref("security.ssl3.dhe_dss_aes_256_sha", true);
 pref("security.ssl3.rsa_aes_256_sha", true);
@@ -148,9 +148,9 @@ pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
 // Size explicitly set by the user. Used when smart_size.enabled == false
-//@line 69 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 69 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         256000);
-//@line 73 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 73 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -159,7 +159,7 @@ pref("browser.cache.disk_cache_ssl",        true);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 82 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 82 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -170,7 +170,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 98 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 98 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether or not indexedDB is enabled.
 pref("dom.indexedDB.enabled", true);
@@ -245,13 +245,13 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 512000);
 
-//@line 176 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 176 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 179 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 179 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 182 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 182 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 184 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 184 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -265,23 +265,27 @@ pref("gfx.color_management.rendering_intent", 0);
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 198 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 198 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", false);
-//@line 202 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 202 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-pref("gfx.font_rendering.harfbuzz.level", 2);
+// see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
+//@line 205 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
+// use harfbuzz for default (0x01) + arabic (0x02) + hebrew (0x04)
+pref("gfx.font_rendering.harfbuzz.scripts", 7);
+//@line 211 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 211 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 218 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 235 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 242 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 238 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 245 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -621,12 +625,14 @@ pref("dom.storage.default_quota",      5120);
 pref("dom.send_after_paint_to_content", false);
 
 // Timeout clamp in ms for timeouts we clamp
-pref("dom.min_timeout_value", 10);
+pref("dom.min_timeout_value", 4);
+// And for background windows
+pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 581 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 590 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 583 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 592 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -641,7 +647,7 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 600 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 609 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
@@ -687,9 +693,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 646 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 655 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 648 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 657 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -858,7 +864,6 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
-pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -887,9 +892,6 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
-// lk, Sri Lanka, .<Lanka> and .<Ilangai>
-pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
-pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -899,14 +901,11 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
-// sy, Syria, .<Souria>
-pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
-pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -992,7 +991,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 956 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 958 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1059,10 +1058,10 @@ pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/in
 pref("intl.charsetmenu.browser.static",     "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.more1",      "ISO-8859-1, ISO-8859-15, IBM850, x-mac-roman, windows-1252, ISO-8859-14, ISO-8859-7, x-mac-greek, windows-1253, x-mac-icelandic, ISO-8859-10, ISO-8859-3");
 pref("intl.charsetmenu.browser.more2",      "ISO-8859-4, ISO-8859-13, windows-1257, IBM852, ISO-8859-2, x-mac-ce, windows-1250, x-mac-croatian, IBM855, ISO-8859-5, ISO-IR-111, KOI8-R, x-mac-cyrillic, windows-1251, IBM866, KOI8-U, x-mac-ukrainian, ISO-8859-16, x-mac-romanian");
-pref("intl.charsetmenu.browser.more3",      "GB2312, x-gbk, gb18030, HZ-GB-2312, ISO-2022-CN, Big5, Big5-HKSCS, x-euc-tw, EUC-JP, ISO-2022-JP, Shift_JIS, EUC-KR, x-windows-949, x-johab, ISO-2022-KR");
+pref("intl.charsetmenu.browser.more3",      "GB2312, gbk, gb18030, HZ-GB-2312, ISO-2022-CN, Big5, Big5-HKSCS, x-euc-tw, EUC-JP, ISO-2022-JP, Shift_JIS, EUC-KR, x-windows-949, x-johab, ISO-2022-KR");
 pref("intl.charsetmenu.browser.more4",      "armscii-8, GEOSTD8, TIS-620, ISO-8859-11, windows-874, IBM857, ISO-8859-9, x-mac-turkish, windows-1254, x-viet-tcvn5712, VISCII, x-viet-vps, windows-1258, x-mac-devanagari, x-mac-gujarati, x-mac-gurmukhi");
 pref("intl.charsetmenu.browser.more5",      "ISO-8859-6, windows-1256, IBM864, ISO-8859-8-I, windows-1255, ISO-8859-8, IBM862");
-pref("intl.charsetmenu.browser.unicode",    "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
+pref("intl.charsetmenu.browser.unicode",    "UTF-8, UTF-16LE, UTF-16BE");
 pref("intl.charsetmenu.mailedit",           "chrome://global/locale/intl.properties");
 pref("intl.charsetmenu.browser.cache",      "");
 pref("intl.charsetmenu.mailview.cache",     "");
@@ -1381,20 +1380,20 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1345 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1347 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1356 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1358 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1371 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1373 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1431,9 +1430,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1837 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1833 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1839 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1835 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1465,16 +1464,16 @@ pref("font.name-list.monospace.el", "Lucida Grande");
 pref("font.name-list.cursive.el", "Lucida Grande");
 pref("font.name-list.fantasy.el", "Lucida Grande");
 
-pref("font.name.serif.he", "Raanana");
-pref("font.name.sans-serif.he", "Arial Hebrew");
-pref("font.name.monospace.he", "Arial Hebrew");
-pref("font.name.cursive.he", "Corsiva Hebrew");
-pref("font.name.fantasy.he", "Corsiva Hebrew");
-pref("font.name-list.serif.he", "Raanana");
-pref("font.name-list.sans-serif.he", "Arial Hebrew");
-pref("font.name-list.monospace.he", "Arial Hebrew");
-pref("font.name-list.cursive.he", "Corsiva Hebrew");
-pref("font.name-list.fantasy.he", "Corsiva Hebrew");
+pref("font.name.serif.he", "Times New Roman");
+pref("font.name.sans-serif.he", "Arial");
+pref("font.name.monospace.he", "Courier New");
+pref("font.name.cursive.he", "Times New Roman");
+pref("font.name.fantasy.he", "Times New Roman");
+pref("font.name-list.serif.he", "Times New Roman");
+pref("font.name-list.sans-serif.he", "Arial");
+pref("font.name-list.monospace.he", "Courier New");
+pref("font.name-list.cursive.he", "Times New Roman");
+pref("font.name-list.fantasy.he", "Times New Roman");
 
 pref("font.name.serif.ja", "Hiragino Mincho Pro"); 
 pref("font.name.sans-serif.ja", "Hiragino Kaku Gothic Pro"); 
@@ -1858,21 +1857,17 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2265 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2261 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2465 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2461 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2561 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2730 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2830 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3005 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3105 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3025 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3131 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3151 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3159 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3033 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1946,9 +1941,9 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3238 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3112 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3243 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3117 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
 pref("layers.acceleration.disabled", false);
@@ -1956,7 +1951,7 @@ pref("layers.acceleration.disabled", false);
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3262 "/builds/slave/m-2.0-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3136 "/builds/slave/rel-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
