@@ -1,4 +1,4 @@
-//@line 41 "/builds/slave/m-192-osx-xr/build/toolkit/components/viewconfig/content/config.js"
+//@line 40 "/builds/slave/rel-osx64-xr/build/toolkit/components/viewconfig/content/config.js"
 
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString = Components.interfaces.nsISupportsString;
@@ -216,6 +216,8 @@ var gPrefListener =
       }
       if (gPrefView == gPrefArray)
         view.treebox.rowCountChanged(index, 1);
+      else
+        FilterPrefs();
     }
   }
 };
@@ -295,17 +297,14 @@ function onConfigLoad()
 // Unhide the warning message
 function ShowPrefs()
 {
-  var prefCount = { value: 0 };
-  var prefArray = gPrefBranch.getChildList("", prefCount);
+  var prefArray = gPrefBranch.getChildList("");
 
-  for (var i = 0; i < prefCount.value; ++i) 
-  {
-    var prefName = prefArray[i];
+  prefArray.forEach(function (prefName) {
     if (/^capability\./.test(prefName)) // avoid displaying "private" preferences
-      continue;
+      return;
 
     fetchPref(prefName, gPrefArray.length);
-  }
+  });
 
   var descending = document.getElementsByAttribute("sortDirection", "descending");
   if (descending.item(0)) {
@@ -551,26 +550,27 @@ function ModifyPref(entry)
     if (!entry.valueCol && !gPromptService.select(window, title, entry.prefCol, 2, [false, true], check))
       return false;
     gPrefBranch.setBoolPref(entry.prefCol, check.value);
-  }
-  else if (entry.typeCol == nsIPrefBranch.PREF_INT) {
-    var params = { windowTitle: title,
-                   label: entry.prefCol,
-                   value: entry.valueCol,
-                   cancelled: true };
-    window.openDialog("chrome://global/content/configIntValue.xul", "_blank",
-                      "chrome,titlebar,centerscreen,modal", params);
-    if (params.cancelled)
-      return false;
-    gPrefBranch.setIntPref(entry.prefCol, params.value);
-  }
-  else {
+  } else {
     var result = { value: entry.valueCol };
     var dummy = { value: 0 };
     if (!gPromptService.prompt(window, title, entry.prefCol, result, null, dummy))
       return false;
-    var supportsString = Components.classes[nsSupportsString_CONTRACTID].createInstance(nsISupportsString);
-    supportsString.data = result.value;
-    gPrefBranch.setComplexValue(entry.prefCol, nsISupportsString, supportsString);
+    if (entry.typeCol == nsIPrefBranch.PREF_INT) {
+      // | 0 converts to integer or 0; - 0 to float or NaN.
+      // Thus, this check should catch all cases.
+      var val = result.value | 0;
+      if (val != result.value - 0) {
+        var err_title = gConfigBundle.getString("nan_title");
+        var err_text = gConfigBundle.getString("nan_text");
+        gPromptService.alert(window, err_title, err_text);
+        return false;
+      }
+      gPrefBranch.setIntPref(entry.prefCol, val);
+    } else {
+      var supportsString = Components.classes[nsSupportsString_CONTRACTID].createInstance(nsISupportsString);
+      supportsString.data = result.value;
+      gPrefBranch.setComplexValue(entry.prefCol, nsISupportsString, supportsString);
+    }
   }
 
   gPrefService.savePrefFile(null);
