@@ -1,20 +1,19 @@
-//@line 37 "/builds/slave/m-192-osx-xr/build/toolkit/content/macWindowMenu.js"
+//@line 37 "/builds/slave/rel-osx64-xr/build/toolkit/content/macWindowMenu.js"
 
-function checkFocusedWindow()
+function macWindowMenuDidShow()
 {
   var windowManagerDS =
     Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator']
               .getService(Components.interfaces.nsIWindowDataSource);
-
   var sep = document.getElementById("sep-window-list");
   // Using double parens to avoid warning
   while ((sep = sep.nextSibling)) {
     var url = sep.getAttribute('id');
     var win = windowManagerDS.getWindowForResource(url);
-    if (win == window) {
+    if (win.document.documentElement.getAttribute("inwindowmenu") == "false")
+      sep.hidden = true;
+    else if (win == window)
       sep.setAttribute("checked", "true");
-      break;
-    }
   }
 }
 
