@@ -1,4 +1,4 @@
-//@line 45 "/builds/slave/m-192-osx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -20,6 +20,9 @@ Cu.import("resource://gre/modules/PluralForm.jsm");
 const nsIDM = Ci.nsIDownloadManager;
 
 let gDownloadManager = Cc["@mozilla.org/download-manager;1"].getService(nsIDM);
+let gDownloadManagerUI = Cc["@mozilla.org/download-manager-ui;1"].
+                         getService(Ci.nsIDownloadManagerUI);
+
 let gDownloadListener = null;
 let gDownloadsView = null;
 let gSearchBox = null;
@@ -124,6 +127,8 @@ function downloadCompleted(aDownload)
 
     if (gDownloadManager.activeDownloadCount == 0)
       document.title = document.documentElement.getAttribute("statictitle");
+
+    gDownloadManagerUI.getAttention();
   }
   catch (e) { }
 }
@@ -246,7 +251,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 306 "/builds/slave/m-192-osx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 311 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -267,6 +272,15 @@ function openDownload(aDownload)
     }
   }
   try {
+    try {
+      let download = gDownloadManager.getDownload(aDownload.getAttribute("dlid"));
+      let mimeInfo = download.MIMEInfo;
+      if (mimeInfo.preferredAction == mimeInfo.useHelperApp) {
+        mimeInfo.launchWithFile(f);
+        return;
+      }
+    } catch (ex) {
+    }
     f.launch();
   } catch (ex) {
     // if launch fails, try sending it through the system's external
@@ -420,6 +434,8 @@ function Startup()
       e.preventDefault();
     }
   }, false);
+
+//@line 501 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/content/downloads.js"
 }
 
 function Shutdown()
@@ -475,7 +491,7 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 539 "/builds/slave/m-192-osx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 561 "/builds/slave/m-beta-osx64-xr/build/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
@@ -622,12 +638,25 @@ function buildContextMenu(aEvent)
 
   return false;
 }
-
 ////////////////////////////////////////////////////////////////////////////////
 //// Drag and Drop
-
 var gDownloadDNDObserver =
 {
+  onDragStart: function (aEvent)
+  {
+    if (!gDownloadsView.selectedItem)
+      return;
+    var dl = gDownloadsView.selectedItem;
+    var f = getLocalFileFromNativePathOrUrl(dl.getAttribute("file"));
+    if (!f.exists())
+      return;
+
+    var dt = aEvent.dataTransfer;
+    dt.mozSetDataAt("application/x-moz-file", f, 0);
+    dt.effectAllowed = "copyMove";
+    dt.addElement(dl);
+  },
+
   onDragOver: function (aEvent)
   {
     var types = aEvent.dataTransfer.types;
@@ -1096,11 +1125,11 @@ function buildDownloadList(aForceBuild)
   }
 
   try {
-    gStmt.bindInt32Parameter(0, nsIDM.DOWNLOAD_NOTSTARTED);
-    gStmt.bindInt32Parameter(1, nsIDM.DOWNLOAD_DOWNLOADING);
-    gStmt.bindInt32Parameter(2, nsIDM.DOWNLOAD_PAUSED);
-    gStmt.bindInt32Parameter(3, nsIDM.DOWNLOAD_QUEUED);
-    gStmt.bindInt32Parameter(4, nsIDM.DOWNLOAD_SCANNING);
+    gStmt.bindByIndex(0, nsIDM.DOWNLOAD_NOTSTARTED);
+    gStmt.bindByIndex(1, nsIDM.DOWNLOAD_DOWNLOADING);
+    gStmt.bindByIndex(2, nsIDM.DOWNLOAD_PAUSED);
+    gStmt.bindByIndex(3, nsIDM.DOWNLOAD_QUEUED);
+    gStmt.bindByIndex(4, nsIDM.DOWNLOAD_SCANNING);
   } catch (e) {
     // Something must have gone wrong when binding, so clear and quit
     gStmt.reset();
@@ -1111,6 +1140,7 @@ function buildDownloadList(aForceBuild)
   gBuilder = setTimeout(function() {
     // Start building the list and select the first item
     stepListBuilder(1);
+    gDownloadsView.selectedIndex = 0;
 
     // We just tried to add a single item, so we probably need to enable
     updateClearListButton();
